## 102003017
### It finds topsis Score and based on that calculates the rank.

### Installation
## pip install 102003017



## License
### © 2023 Srishti Sharma

### This repository is licensed under the MIT license. See LICENSE for details.